@@ -3,8 +3,8 @@
  * mp3splt-gtk -- utility based on mp3splt,
  *                for mp3/ogg splitting without decoding
  *
- * Copyright: (C) 2005-2006 Munteanu Alexandru
- * Contact: io_alex_2002@yahoo.fr
+ * Copyright: (C) 2005-2009 Alexandru Munteanu
+ * Contact: io_fx@yahoo.fr
  *
  * http://mp3splt.sourceforge.net/
  *
@@ -71,7 +71,7 @@ enum
   };
 
 //results of the freedb search
-freedb_results *search_results;
+const splt_freedb_results *search_results;
 //the selected entry id
 gint selected_id = -1;
 
@@ -90,9 +90,9 @@ extern GtkWidget *output_entry;
 
 //add a row to the table
 void add_freedb_row(gchar *album_name, 
-		    gint album_id,
-		    gint *revisions,
-		    gint revisions_number)
+                    gint album_id,
+                    gint *revisions,
+                    gint revisions_number)
 {
   //father iter
   GtkTreeIter iter;
@@ -107,29 +107,28 @@ void add_freedb_row(gchar *album_name,
   gtk_tree_store_append (GTK_TREE_STORE(model), &iter,NULL);
   //sets the father
   gtk_tree_store_set (GTK_TREE_STORE(model), &iter,
-		      ALBUM_NAME, album_name,
-		      NUMBER, album_id,
-		      -1);
+                      ALBUM_NAME, album_name,
+                      NUMBER, album_id,
+                      -1);
   
   gchar *number;
   gint malloc_number = strlen(album_name) + 20;
   //allocate memory
-  number = (gchar *)
-    malloc(malloc_number*sizeof(gchar *));
+  number = malloc(malloc_number * sizeof(gchar *));
   gint i;
   for(i = 0; i < revisions_number; i++)
     {
       g_snprintf(number,malloc_number,
-		"%s Revision %d",album_name, revisions[i]);
+                "%s Revision %d",album_name, revisions[i]);
       
       //sets the children..
       gtk_tree_store_append (GTK_TREE_STORE(model),
-			     &child_iter, &iter);
+                             &child_iter, &iter);
       gtk_tree_store_set (GTK_TREE_STORE(model),
-			  &child_iter,
-			  ALBUM_NAME, number,
-			  NUMBER, album_id+i+1,
-			  -1);
+                          &child_iter,
+                          ALBUM_NAME, number,
+                          NUMBER, album_id+i+1,
+                          -1);
     }
   freedb_table_number++;
   //free memory
@@ -141,8 +140,8 @@ GtkTreeModel *create_freedb_model()
 {
   GtkTreeStore *model;
   model = gtk_tree_store_new (FREEDB_TABLE,
-			      G_TYPE_STRING,
-			      G_TYPE_INT);
+                              G_TYPE_STRING,
+                              G_TYPE_INT);
 
   return GTK_TREE_MODEL (model);
 }
@@ -172,65 +171,64 @@ void create_freedb_columns (GtkTreeView *tree_view)
   
   //album title
   renderer = GTK_CELL_RENDERER_TEXT(gtk_cell_renderer_text_new ());
-  g_object_set_data(G_OBJECT(renderer), "col", (gint *)ALBUM_NAME);
+  g_object_set_data(G_OBJECT(renderer), "col", GINT_TO_POINTER(ALBUM_NAME));
   name_column = gtk_tree_view_column_new_with_attributes 
-    ((gchar *)_("Album title"), GTK_CELL_RENDERER(renderer),
+    (_("Album title"), GTK_CELL_RENDERER(renderer),
      "text", ALBUM_NAME, NULL);
 
   //appends columns to the list of columns of tree_view
   gtk_tree_view_insert_column (GTK_TREE_VIEW (tree_view),
-			       GTK_TREE_VIEW_COLUMN (name_column),
-			       ALBUM_NAME);
+                               GTK_TREE_VIEW_COLUMN (name_column),
+                               ALBUM_NAME);
 
   //middle alignment of the column name
   gtk_tree_view_column_set_alignment(GTK_TREE_VIEW_COLUMN(name_column),
-				     0.5);
+                                     0.5);
   gtk_tree_view_column_set_sizing (GTK_TREE_VIEW_COLUMN(name_column),
-				   GTK_TREE_VIEW_COLUMN_AUTOSIZE);
+                                   GTK_TREE_VIEW_COLUMN_AUTOSIZE);
   gtk_tree_view_column_set_expand (GTK_TREE_VIEW_COLUMN(name_column),
-				   TRUE);
+                                   TRUE);
 
   //number of the album title
   renderer = GTK_CELL_RENDERER_TEXT(gtk_cell_renderer_text_new ());
-  g_object_set_data(G_OBJECT(renderer), "col", (gint *)NUMBER);
-  number_column = gtk_tree_view_column_new_with_attributes 
-    ((gchar *)_("No"), GTK_CELL_RENDERER(renderer),
-     "text", NUMBER, NULL);
+  g_object_set_data(G_OBJECT(renderer), "col", GINT_TO_POINTER(NUMBER));
+  number_column = gtk_tree_view_column_new_with_attributes
+    (_("No"), GTK_CELL_RENDERER(renderer), "text", NUMBER, NULL);
 
   //appends columns to the list of columns of tree_view
   gtk_tree_view_insert_column (GTK_TREE_VIEW (tree_view),
-			       GTK_TREE_VIEW_COLUMN (number_column),
-			       NUMBER);
+                               GTK_TREE_VIEW_COLUMN (number_column),
+                               NUMBER);
 
   //middle alignment of the number name
   gtk_tree_view_column_set_alignment(GTK_TREE_VIEW_COLUMN(number_column),
-				     0.5);
+                                     0.5);
   gtk_tree_view_column_set_sizing (GTK_TREE_VIEW_COLUMN(number_column),
-				   GTK_TREE_VIEW_COLUMN_AUTOSIZE);
+                                   GTK_TREE_VIEW_COLUMN_AUTOSIZE);
   
   //resize.
   gtk_tree_view_column_set_resizable (GTK_TREE_VIEW_COLUMN(name_column),
-				      TRUE);
+                                      TRUE);
 }
 
 //when closing the new window after detaching
 void close_freedb_popup_window_event( GtkWidget *window,
-				      gpointer data )
+                                      gpointer data )
 {
   GtkWidget *window_child;
 
   window_child = gtk_bin_get_child(GTK_BIN(window));
 
   gtk_widget_reparent(GTK_WIDGET(window_child),
-		      GTK_WIDGET(freedb_handle_box));
+                      GTK_WIDGET(freedb_handle_box));
 
   gtk_widget_destroy(window);
 }
 
 //when we detach the handle
 void handle_freedb_detached_event (GtkHandleBox *handlebox,
-				 GtkWidget *widget,
-				 gpointer data)
+                                 GtkWidget *widget,
+                                 gpointer data)
 {
   //new window
   GtkWidget *window;
@@ -238,15 +236,15 @@ void handle_freedb_detached_event (GtkHandleBox *handlebox,
   gtk_widget_reparent(GTK_WIDGET(widget), GTK_WIDGET(window));
 
   g_signal_connect (G_OBJECT (window), "delete_event",
-		    G_CALLBACK (close_freedb_popup_window_event),
-		    NULL);
+                    G_CALLBACK (close_freedb_popup_window_event),
+                    NULL);
 
   gtk_widget_show(GTK_WIDGET(window));
 }
 
 //freedb selection has changed
 void freedb_selection_changed(GtkTreeSelection *selection,
-			      gpointer data)
+                              gpointer data)
 {
   GtkTreeIter iter;
   GtkTreeModel *model;
@@ -257,17 +255,17 @@ void freedb_selection_changed(GtkTreeSelection *selection,
   
   //if we have selected
   if(gtk_tree_selection_get_selected(selection,
-				     &model,
-				     &iter))
+                                     &model,
+                                     &iter))
     {
       gchar *info;
       gtk_tree_model_get (model, &iter,
                           ALBUM_NAME, &info,
                           NUMBER, &selected_id,
-			  -1);
+                          -1);
       
       gtk_entry_set_text(GTK_ENTRY(freedb_selected_entry),
-			 info);
+                         info);
       g_free(info);
       
       gtk_widget_set_sensitive(GTK_WIDGET(freedb_add_button), TRUE);
@@ -298,23 +296,23 @@ void remove_all_freedb_rows ()
 //the third result returns us if the result must be freed 
 //or not
 gchar *transform_to_utf8(gchar *text, 
-			 gint free_or_not,
-			 gint *must_be_freed)
+                         gint free_or_not,
+                         gint *must_be_freed)
 {
   gchar *temp;
-  guint test;
+
+  gsize bytes_read;
+  gsize bytes_written;
+
   if(!(g_utf8_validate (text, -1,NULL)) &&
      (text != NULL))
     {
-      temp = g_convert (text, -1,
-			"UTF-8",
-			"ISO-8859-1",
-			&test,&test, NULL);
+      temp = g_convert(text, -1, "UTF-8", "ISO-8859-1", &bytes_read, &bytes_written, NULL);
       if (free_or_not)
-	g_free(text);
-	  
+        g_free(text);
+          
       *must_be_freed = TRUE;
-	  
+          
       return temp;
     }
   
@@ -330,26 +328,23 @@ void freedb_search(gpointer *data)
   gdk_threads_enter();
   
   gtk_widget_set_sensitive(GTK_WIDGET(freedb_add_button),
-			   FALSE);
+                           FALSE);
   gtk_widget_set_sensitive(GTK_WIDGET(freedb_search_button), 
-			   FALSE);
+                           FALSE);
   gtk_entry_set_editable (GTK_ENTRY (freedb_entry), FALSE);
   
-  put_status_message((gchar *)
-		     _("please wait... contacting freedb.org"));
+  put_status_message(_("please wait... contacting freedb.org"));
   
   //possible errors
   gint err;
-  gchar *freedb_search = (gchar *)
-    gtk_entry_get_text(GTK_ENTRY(freedb_entry));
+  const gchar *freedb_search = gtk_entry_get_text(GTK_ENTRY(freedb_entry));
   
   //unlock gtk
   gdk_threads_leave();
   
   search_results = 
-    libmp3splt_get_freedb_search(the_state,
-				 freedb_search,
-				 &err);
+    mp3splt_get_freedb_search(the_state, freedb_search, &err,
+                              SPLT_FREEDB_SEARCH_TYPE_CDDB_CGI, "\0",-1);
   
   //lock gtk
   gdk_threads_enter();
@@ -360,7 +355,7 @@ void freedb_search(gpointer *data)
   remove_all_freedb_rows ();
   //erase the selected entry
   gtk_entry_set_text(GTK_ENTRY(freedb_selected_entry),
-		     "");
+                     "");
   
   //if no error
   if (err >= 0)
@@ -368,42 +363,42 @@ void freedb_search(gpointer *data)
       //we put the results in the table
       gint i;
       for (i = 0; i< search_results->number;i++)
-	{
-	  gint must_be_free;
-	  search_results->results[i].name =
-	    transform_to_utf8(search_results->results[i].name,
-			      TRUE, &must_be_free);
-	  add_freedb_row(search_results->results[i].name,
-			 search_results->results[i].id,
-			 search_results->results[i].revisions,
-			 search_results->results[i].revision_number);
-	}
+        {
+          gint must_be_free;
+          search_results->results[i].name =
+            transform_to_utf8(search_results->results[i].name,
+                              TRUE, &must_be_free);
+          add_freedb_row(search_results->results[i].name,
+                         search_results->results[i].id,
+                         search_results->results[i].revisions,
+                         search_results->results[i].revision_number);
+        }
       
       if (search_results->number > 0)
-	{
-	  //we select the first result
-	  GtkTreeModel *model;
-	  GtkTreePath *path;
-	  GtkTreeIter iter;
-	  GtkTreeSelection *selection;
-	  selection = 
-	    gtk_tree_view_get_selection(GTK_TREE_VIEW(freedb_tree));
+        {
+          //we select the first result
+          GtkTreeModel *model;
+          GtkTreePath *path;
+          GtkTreeIter iter;
+          GtkTreeSelection *selection;
+          selection = 
+            gtk_tree_view_get_selection(GTK_TREE_VIEW(freedb_tree));
       
-	  //we get the model
-	  model = gtk_tree_view_get_model(GTK_TREE_VIEW(freedb_tree));
-	  //we get the path
-	  path = gtk_tree_path_new_from_indices (0 ,-1);
-	  //we get iter
-	  gtk_tree_model_get_iter(model, &iter, path);
-	  gtk_tree_selection_select_iter(selection,
-					 &iter);
-	  //we free the path
-	  gtk_tree_path_free(path);
-	}
+          //we get the model
+          model = gtk_tree_view_get_model(GTK_TREE_VIEW(freedb_tree));
+          //we get the path
+          path = gtk_tree_path_new_from_indices (0 ,-1);
+          //we get iter
+          gtk_tree_model_get_iter(model, &iter, path);
+          gtk_tree_selection_select_iter(selection,
+                                         &iter);
+          //we free the path
+          gtk_tree_path_free(path);
+        }
     }
   
   gtk_widget_set_sensitive(GTK_WIDGET(freedb_search_button), 
-			   TRUE);
+                           TRUE);
   gtk_entry_set_editable (GTK_ENTRY (freedb_entry), TRUE);
   
   //unlock gtk
@@ -413,12 +408,12 @@ void freedb_search(gpointer *data)
 void freedb_search_start_thread()
 {
   g_thread_create((GThreadFunc)freedb_search,
-		  NULL, TRUE, NULL);
+                  NULL, TRUE, NULL);
 }
 
 //we push the search button
 void freedb_search_button_event( GtkWidget *widget,
-				 gpointer   data )
+                                 gpointer   data )
 {
   freedb_search_start_thread();
 }
@@ -426,190 +421,207 @@ void freedb_search_button_event( GtkWidget *widget,
 //search entry backspace event
 //when we push Enter for the search entry
 void freedb_entry_activate_event (GtkEntry *entry,
-				  gpointer data)
+                                  gpointer data)
 {
   freedb_search_start_thread();
 }
 
 //returns the number of splitpoints
 //we put the new splitpoints in "the_state"
-gint write_freedbfile_and_get_splitpoints(int *err)
+void write_freedbfile(int *err)
 {
   //we check if the output format is correct
-  char *data = (char *)
-    gtk_entry_get_text(GTK_ENTRY(output_entry));
-  int error = MP3SPLT_OUTPUT_FORMAT_OK;
-  libmp3splt_checkparse_outformat(the_state,
-				  strdup(data),
-				  &error);
+  const char *data = gtk_entry_get_text(GTK_ENTRY(output_entry));
+  gint error = SPLT_OUTPUT_FORMAT_OK;
+  mp3splt_set_oformat(the_state, data, &error);
   
   //unlock gtk
   gdk_threads_enter();
   
   print_status_bar_confirmation(error);
   
-  put_status_message((gchar *)
-		     _("please wait... contacting freedb.org"));
+  put_status_message(_("please wait... contacting freedb.org"));
   
   //we suppose directory exists
   //it should be created when mp3splt-gtk starts
   gchar mp3splt_dir[14] = ".mp3splt-gtk";
   //home directory
-  gchar *home_dir = (gchar *)g_get_home_dir();
+  const gchar *home_dir = g_get_home_dir();
   gchar *filename;
   gint malloc_number = strlen(mp3splt_dir) + 
     strlen(home_dir) + 20;
   //allocate memory
-  filename = (gchar *)
-    malloc(malloc_number * sizeof(gchar *));
+  filename = malloc(malloc_number * sizeof(gchar *));
   
   g_snprintf(filename,malloc_number,
-	     "%s%s%s%s%s", home_dir,
-	     G_DIR_SEPARATOR_S, mp3splt_dir,
-	     G_DIR_SEPARATOR_S, "query.cddb");
-  
-  //unlock gtk
-  gdk_threads_leave();
-  
-  //we write the freedb file ...
-  libmp3splt_write_freedb_file_result(the_state, selected_id,
-				      filename, err);
-  
-  //here we have in err a possible error from the freedb
-  print_status_bar_confirmation(*err);
-  
-  //lock gtk
-  gdk_threads_enter();
-  
-  //we put the output default option
-  the_state->options.option_output_is_default = 
-    get_checked_output_radio_box();
-  
-  gint max_tracks = 0;
-  //we get the information from the cddb file
-  //we print err when we leave this function
-  max_tracks = libmp3splt_get_cddb_splitpoints_from_file
-    (the_state,filename, err);
-  
-  //freeing memory
-  g_free(filename);
+             "%s%s%s%s%s", home_dir,
+             G_DIR_SEPARATOR_S, mp3splt_dir,
+             G_DIR_SEPARATOR_S, "query.cddb");
   
   //unlock gtk
   gdk_threads_leave();
 
-  return max_tracks;
+  //we write the freedb file ...
+  mp3splt_write_freedb_file_result(the_state, selected_id,
+                                   filename, err,
+                                   //for now cddb.cgi get file type
+                                   SPLT_FREEDB_GET_FILE_TYPE_CDDB_CGI,
+                                   "\0",-1);
+
+  //lock gtk
+  gdk_threads_enter();
+
+  //here we have in err a possible error from the freedb
+  print_status_bar_confirmation(*err);
+
+  //we put the output default option
+  if(get_checked_output_radio_box())
+    {
+      mp3splt_set_int_option(the_state, SPLT_OPT_OUTPUT_FILENAMES,
+                             SPLT_OUTPUT_DEFAULT);
+    }
+  else
+    {
+      mp3splt_set_int_option(the_state, SPLT_OPT_OUTPUT_FILENAMES,
+                             SPLT_OUTPUT_FORMAT);
+    }
+  
+  //unlock gtk
+  gdk_threads_leave();
+
+  //we get the information from the cddb file
+  //we print err when we leave this function
+  mp3splt_put_cddb_splitpoints_from_file(the_state,filename, err);
+  
+  //freeing memory
+  g_free(filename);
 }
 
 //returns the seconds, minutes, and hudreths
 void get_secs_mins_hundr(gfloat time,
-			 gint *mins,gint *secs, 
-			 gint *hundr)
+                         gint *mins,gint *secs, 
+                         gint *hundr)
 {
   *mins = (gint)(time / 6000);
   *secs = (gint)(time - (*mins * 6000))
     / 100;
   *hundr = (gint)(time - (*mins * 6000)
-		  - (*secs * 100));
+                  - (*secs * 100));
 }
 
 //updates the current splitpoints int the table,
 //from the state splitpoints
 //max_splits is the maximum splitpoints to update
-//type = 2 => cue split
-//type = 1 => cddb split
-void update_splitpoints_from_the_state(gint max_splits,
-				       gint type)
+void update_splitpoints_from_the_state()
 {
+  gint max_splits = 0;
+  gint err = SPLT_OK;
+  const splt_point *points = mp3splt_get_splitpoints(the_state, &max_splits,&err);
+  print_status_bar_confirmation(err);
+  
   //only if we have splitpoints
   if (max_splits > 0)
+  {
+    //erase rows from the splitpoints table
+    remove_all_rows(NULL,NULL);
+    gint i;
+
+    //for each splitpoint, we put it in the table
+    for(i = 0; i < max_splits;i++)
     {
-      //erase rows from the splitpoints table
-      remove_all_rows(NULL,NULL);
-      
-      gint i;
-      //for each splitpoint, we put it in the table
-      for(i = 0; i < max_splits+1;i++)
-	{
-	  //we get the minutes, seconds and hudreths
-	  get_secs_mins_hundr(the_state->split.splitpoints[i],
-			      &spin_mins, &spin_secs,
-			      &spin_hundr_secs);
-	  
-	  //last splitpoint for cue and cddb add extra line
-	  if (i == max_splits)
-	    {
-	      //cddb split
-	      if (type == 2)
-		{
-		  spin_mins = 2000;spin_secs = 0;spin_hundr_secs = 0;
-		}
-	      
-	      g_snprintf(current_description, 255, "%s",
-			 _("description here"));
-	    }
-	  else
-	    {
-	      gint must_be_free;
-	      gchar *result_utf8 = (gchar *)the_state->split.fn[i];
-	      result_utf8 = transform_to_utf8(result_utf8, 
-					      FALSE, &must_be_free);
-	      g_snprintf(current_description,255,
-			 "%s", result_utf8);
-	      
-	      //free memory
-	      if (must_be_free)
-		g_free(result_utf8);
-	    }
-	  
-	  //we add the row
-	  add_row(NULL,NULL);
-	}
-      
-      //we reput the "description here" name
-      g_snprintf(current_description, 255, "%s",
-		 _("description here"));
-      
-      update_minutes_from_spinner(NULL,NULL);
-      update_seconds_from_spinner(NULL,NULL);
-      update_hundr_secs_from_spinner(NULL,NULL);
-      update_add_button();
+      //ugly hack because we use maximum ints in the GUI
+      //-GUI must be changed to accept long values
+      long old_point_value = points[i].value;
+      int point_value = (int) old_point_value;
+      if (old_point_value > INT_MAX)
+      {
+        point_value = INT_MAX;
+      }
+
+      //we get the minutes, seconds and hundreths
+      get_secs_mins_hundr(point_value,
+          &spin_mins, &spin_secs,
+          &spin_hundr_secs);
+
+      gint must_be_free = FALSE;
+      gchar *result_utf8 = points[i].name;
+
+      if (result_utf8 != NULL)
+      {
+        result_utf8 = transform_to_utf8(result_utf8, 
+            FALSE, &must_be_free);
+
+        g_snprintf(current_description,255,
+            "%s", result_utf8);
+      }
+      else
+      {
+        //we reput the "description here" name
+        g_snprintf(current_description, 255, "%s",
+            _("description here"));
+      }
+
+      //free memory
+      if (must_be_free)
+      {
+        g_free(result_utf8);
+      }
+
+      //we add the row
+      if (points[i].type == SPLT_SPLITPOINT)
+      {
+        add_row(TRUE);
+      }
+      else if (points[i].type == SPLT_SKIPPOINT)
+      {
+        add_row(FALSE);
+      }
     }
+
+    //we reput the "description here" name
+    g_snprintf(current_description, 255, "%s",
+        _("description here"));
+
+    update_minutes_from_spinner(NULL,NULL);
+    update_seconds_from_spinner(NULL,NULL);
+    update_hundr_secs_from_spinner(NULL,NULL);
+    update_add_button();
+  }
 }
 
 void put_freedb_splitpoints(gpointer *data)
 {
+  //possible errors
+  gint err;
+
   //lock gtk
   gdk_threads_enter();
   gtk_widget_set_sensitive(GTK_WIDGET(freedb_add_button), 
-			   FALSE);
+                           FALSE);  
   gdk_threads_leave();
   
-  gint max_splits = 0;
-  //possible errors
-  gint err;
-  max_splits = write_freedbfile_and_get_splitpoints(&err);
+  write_freedbfile(&err);
   
   //lock gtk
   gdk_threads_enter();
   
-  //1 means cddb split
-  update_splitpoints_from_the_state(max_splits, 1);
+  update_splitpoints_from_the_state();
   
   //here we have in err a possible error from the freedb
   print_status_bar_confirmation(err);
   
   gtk_widget_set_sensitive(GTK_WIDGET(freedb_add_button), 
-			   TRUE);
+                           TRUE);
   //unlock gtk
   gdk_threads_leave();
 }
 
 //event for the freedb add button when clicked
 void freedb_add_button_clicked_event(GtkButton *button,
-				     gpointer data)
+                                     gpointer data)
 {
   g_thread_create((GThreadFunc)put_freedb_splitpoints,
-		  NULL, TRUE, NULL);
+                  NULL, TRUE, NULL);
 }
 
 //creates the freedb box
@@ -625,8 +637,8 @@ GtkWidget *create_freedb_frame()
   gtk_container_add(GTK_CONTAINER (freedb_handle_box), GTK_WIDGET(freedb_hbox));
   //handle event
   g_signal_connect(freedb_handle_box, "child-detached",
-		   G_CALLBACK(handle_freedb_detached_event),
-		   NULL);
+                   G_CALLBACK(handle_freedb_detached_event),
+                   NULL);
   
   //vertical box
   GtkWidget *freedb_vbox;
@@ -640,23 +652,22 @@ GtkWidget *create_freedb_frame()
   gtk_box_pack_start (GTK_BOX(freedb_vbox), search_hbox , FALSE, FALSE, 3);
   //top label
   GtkWidget *label;
-  label = gtk_label_new((gchar *)_("Search freedb.org : "));
+  label = gtk_label_new(_("Search freedb2.org : "));
   gtk_box_pack_start (GTK_BOX(search_hbox), label , FALSE, FALSE, 0);
   //top entry
   freedb_entry = gtk_entry_new();
   gtk_entry_set_editable (GTK_ENTRY (freedb_entry), TRUE);
   gtk_box_pack_start (GTK_BOX(search_hbox), freedb_entry , TRUE, TRUE, 0);
   g_signal_connect (G_OBJECT (freedb_entry), "activate",
-		    G_CALLBACK (freedb_entry_activate_event), NULL);
+                    G_CALLBACK (freedb_entry_activate_event), NULL);
   
   //search button
   freedb_search_button = (GtkWidget *)
-    create_cool_button(GTK_STOCK_FIND,
-		       (gchar *)_("_Search"),FALSE);
+    create_cool_button(GTK_STOCK_FIND, _("_Search"),FALSE);
   g_signal_connect (G_OBJECT (freedb_search_button), "clicked",
-		    G_CALLBACK (freedb_search_button_event), NULL);
+                    G_CALLBACK (freedb_search_button_event), NULL);
   gtk_box_pack_start (GTK_BOX (search_hbox), freedb_search_button,
-		      FALSE, FALSE, 5);
+                      FALSE, FALSE, 5);
   
   /* freedb scrolled window and the tree */
   //create the tree and add it to the scrolled window
@@ -667,14 +678,14 @@ GtkWidget *create_freedb_frame()
   gtk_widget_set_size_request(scrolled_window, 300,130);
   gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW(scrolled_window), GTK_SHADOW_NONE);
   gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolled_window),
-				  GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
+                                  GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
   gtk_box_pack_start (GTK_BOX (freedb_vbox),
-		      scrolled_window, TRUE, TRUE, 5);
+                      scrolled_window, TRUE, TRUE, 5);
   //create columns
   create_freedb_columns (GTK_TREE_VIEW(freedb_tree));
   //add the tree to the scrolled window
   gtk_container_add (GTK_CONTAINER (scrolled_window), 
-		     GTK_WIDGET(freedb_tree));
+                     GTK_WIDGET(freedb_tree));
   
   /* expand all rows after the treeview widget has been realized */
   /*g_signal_connect (freedb_tree, "realize",
@@ -685,7 +696,7 @@ GtkWidget *create_freedb_frame()
   freedb_tree_selection = (GtkWidget *)
     gtk_tree_view_get_selection(GTK_TREE_VIEW(freedb_tree));
   g_signal_connect (G_OBJECT (freedb_tree_selection), "changed",
-		    G_CALLBACK (freedb_selection_changed), NULL);
+                    G_CALLBACK (freedb_selection_changed), NULL);
 
   /* selected album box */
   //horizontal selected box
@@ -694,7 +705,7 @@ GtkWidget *create_freedb_frame()
   gtk_box_pack_start (GTK_BOX(freedb_vbox), selected_hbox , FALSE, FALSE, 3);
   //top selected label
   GtkWidget *label_selected;
-  label_selected = gtk_label_new((gchar *)_("Selected album : "));
+  label_selected = gtk_label_new(_("Selected album : "));
   gtk_box_pack_start (GTK_BOX(selected_hbox), label_selected , FALSE, FALSE, 0);
   //freedb selected entry
   freedb_selected_entry = gtk_entry_new();
@@ -705,15 +716,14 @@ GtkWidget *create_freedb_frame()
   tooltip = gtk_tooltips_new();
   //add button
   freedb_add_button = (GtkWidget *)
-    create_cool_button(GTK_STOCK_ADD,(gchar *)_("_Add splitpoints"),
-		       FALSE);
+    create_cool_button(GTK_STOCK_ADD,_("_Add splitpoints"), FALSE);
   //gtk_button_set_relief(GTK_BUTTON(freedb_add_button), GTK_RELIEF_NONE);
   gtk_widget_set_sensitive(GTK_WIDGET(freedb_add_button), FALSE);
   g_signal_connect (G_OBJECT (freedb_add_button), "clicked",
-		    G_CALLBACK (freedb_add_button_clicked_event), NULL);
+                    G_CALLBACK (freedb_add_button_clicked_event), NULL);
   gtk_box_pack_start (GTK_BOX (selected_hbox), freedb_add_button, FALSE, FALSE, 5);
   gtk_tooltips_set_tip(tooltip, freedb_add_button,
-		       (gchar *)_("set splitpoints to the splitpoints table"),"");
+                       _("set splitpoints to the splitpoints table"),"");
   
   return freedb_handle_box;
 }
