@@ -41,7 +41,7 @@
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #else
-#define VERSION "0.5.4"
+#define VERSION "0.5.6"
 #define PACKAGE_NAME "mp3splt-gtk"
 #endif
 
@@ -214,7 +214,7 @@ void about_window(GtkWidget *widget,
   b2 = (gchar *)_("created from");
   gchar library_version[20];
   mp3splt_get_version(library_version);
-  g_snprintf(b3, 100, "-release of 18/01/09-\n%s libmp3splt %s (%s mp3splt)",
+  g_snprintf(b3, 100, "-release of 16/05/09-\n%s libmp3splt %s (%s mp3splt)",
              b1, library_version, b2);
   
   gtk_about_dialog_set_comments (GTK_ABOUT_DIALOG(dialog), b3);
@@ -335,8 +335,7 @@ void split_button_event (GtkWidget *widget,
           break;
         }
       
-      filename_to_split = (gchar *)
-        gtk_entry_get_text(GTK_ENTRY(entry));
+      filename_to_split = (gchar *) gtk_entry_get_text(GTK_ENTRY(entry));
       
       filename_path_of_split = (gchar *)
         gtk_entry_get_text(GTK_ENTRY(directory_entry));
