@@ -3,7 +3,7 @@
  * mp3splt-gtk -- utility based on mp3splt,
  *                for mp3/ogg splitting without decoding
  *
- * Copyright (c) 2005-2006 Munteanu Alexandru - io_alex_2002@yahoo.fr
+ * Copyright (c) 2005-2009 Alexandru Munteanu - io_fx@yahoo.fr
  *
  * http://mp3splt.sourceforge.net/
  *
@@ -35,6 +35,13 @@
  *
  *********************************************************/
 
+//time structure
+typedef struct
+{
+  long time;
+  float level;
+} silence_wave;
+
 //float comparison
 #define DELTA 5
 
@@ -50,8 +57,8 @@ void cancel_quick_preview_all();
 void cancel_quick_preview();
 void check_cancel_quick_preview(gint i);
 void get_splitpoint_time_left_right(gint *time_left,
-				    gint *time_right,
-				    gint *splitpoint_left);
+                                    gint *time_right,
+                                    gint *splitpoint_left);
 gint mytimer(gpointer data);
 void reset_inactive_progress_bar();
 void reset_inactive_volume_bar();
@@ -63,13 +70,13 @@ void enable_player_buttons();
 void disable_player_buttons();
 void connect_change_buttons();
 void disconnect_change_buttons();
-void connect_with_song(gchar *fname, gint i);
+void connect_with_song(const gchar *fname, gint i);
 void connect_to_player_with_song(gint i);
 void connect_button_event (GtkWidget *widget,
-			   gpointer data);
+                           gpointer data);
 void check_stream();
 void disconnect_button_event (GtkWidget *widget, 
-			      gpointer data);
+                              gpointer data);
 void play_event (GtkWidget *widget, gpointer data);
 void stop_event (GtkWidget *widget, gpointer data);
 void pause_event (GtkWidget *widget, gpointer data);
@@ -79,25 +86,25 @@ void change_song_position();
 GtkWidget *create_player_buttons_hbox(GtkTreeView *tree_view);
 GtkWidget *create_song_informations_hbox();
 gboolean progress_bar_unclick_event (GtkWidget *widget,
-				   GdkEventCrossing *event,
-				     gpointer user_data);
+                                   GdkEventCrossing *event,
+                                     gpointer user_data);
 gboolean progress_bar_click_event (GtkWidget *widget,
-				   GdkEventCrossing *event,
-				   gpointer user_data);
+                                   GdkEventCrossing *event,
+                                   gpointer user_data);
 gfloat get_total_time();
 gfloat get_elapsed_time();
 void refresh_drawing_area();
 void progress_bar_value_changed_event (GtkRange *range,
-				       gpointer user_data);
+                                       gpointer user_data);
 gboolean progress_bar_scroll_event (GtkWidget *widget,
-				    GdkEventScroll *event,
-				    gpointer user_data);
+                                    GdkEventScroll *event,
+                                    gpointer user_data);
 gboolean progress_bar_enter_event (GtkWidget *widget,
-				   GdkEventCrossing *event,
-				   gpointer user_data);
+                                   GdkEventCrossing *event,
+                                   gpointer user_data);
 gboolean progress_bar_leave_event (GtkWidget *widget,
-				   GdkEventCrossing *event,
-				   gpointer user_data);
+                                   GdkEventCrossing *event,
+                                   gpointer user_data);
 GtkWidget *create_song_bar_hbox();
 void print_about_the_song();
 void print_player_filename();
@@ -107,28 +114,28 @@ void change_volume_bar();
 void change_progress_bar();
 GtkWidget *create_filename_player_hbox();
 void change_volume_event(GtkWidget *widget,
-			 gpointer data);
+                         gpointer data);
 gboolean volume_bar_unclick_event (GtkWidget *widget,
-				   GdkEventCrossing *event,
-				   gpointer user_data);
+                                   GdkEventCrossing *event,
+                                   gpointer user_data);
 gboolean volume_bar_click_event (GtkWidget *widget,
-				 GdkEventCrossing *event,
-				 gpointer user_data);
+                                 GdkEventCrossing *event,
+                                 gpointer user_data);
 gboolean volume_bar_enter_event (GtkWidget *widget,
-				 GdkEventCrossing *event,
-				 gpointer user_data);
+                                 GdkEventCrossing *event,
+                                 gpointer user_data);
 gboolean volume_bar_leave_event (GtkWidget *widget,
-				 GdkEventCrossing *event,
-				 gpointer user_data);
+                                 GdkEventCrossing *event,
+                                 gpointer user_data);
 gboolean volume_bar_scroll_event (GtkWidget *widget,
-				  GdkEventScroll *event,
-				  gpointer user_data);
+                                  GdkEventScroll *event,
+                                  gpointer user_data);
 GtkWidget *create_volume_control_box();
 void close_player_popup_window_event( GtkWidget *window,
-				      gpointer data );
+                                      gpointer data );
 void handle_player_detached_event (GtkHandleBox *handlebox,
-				   GtkWidget *widget,
-				   gpointer data);
+                                   GtkWidget *widget,
+                                   gpointer data);
 PangoLayout *get_drawing_text(gchar *str);
 gfloat get_right_drawing_time();
 gfloat get_left_drawing_time();
@@ -136,46 +143,43 @@ gint get_time_hundrsecs(gint time);
 gint get_time_secs(gint time);
 gint get_time_mins(gint time);
 gchar *get_time_for_drawing(gchar *str,
-			    gint time,
-			    gboolean hundr_or_not,
-			    gint *number_of_chars);
+                            gint time,
+                            gboolean hundr_or_not,
+                            gint *number_of_chars);
 gint time_to_pixels(gint width,
-		    gfloat time);
+                    gfloat time);
 gfloat pixels_to_time(gfloat width,
-		      gint pixels);
+                      gint pixels);
 gint get_draw_line_position(gint width,
-			    gfloat time);
+                            gfloat time);
 void draw_motif(GtkWidget *da,GdkGC *gc,
-		gint ylimit,gint x,gint model);
+                gint ylimit,gint x,gint model);
 void draw_marks(gint time_interval,
-		gint left_mark,gint right_mark,
-		gint ylimit, GtkWidget *da, GdkGC *gc);
+                gint left_mark,gint right_mark,
+                gint ylimit, GtkWidget *da, GdkGC *gc);
 //motif for splitpoints
 //draw is false if we draw the splitpoint we move
 void draw_motif_splitpoints(GtkWidget *da, GdkGC *gc,
-			    gint ylimit,gint ylimit2,
-			    gint x,gint draw,
-			    gint current_point_hundr_secs,
-			    gboolean move,
-			    gint number_splitpoint);
+                            gint x,gint draw,
+                            gint current_point_hundr_secs,
+                            gboolean move,
+                            gint number_splitpoint);
 void draw_splitpoints(gint left_mark,
-		      gint right_mark,
-		      gint ylimit,
-		      gint ylimit2,
-		      GtkWidget *da,
-		      GdkGC *gc);
+                      gint right_mark,
+                      GtkWidget *da,
+                      GdkGC *gc);
 gboolean da_expose_event (GtkWidget      *da,
-			  GdkEventExpose *event,
-			  gpointer       data);
+                          GdkEventExpose *event,
+                          gpointer       data);
 gboolean da_press_event (GtkWidget    *da,
-			 GdkEventButton *event,
-			 gpointer     data);
+                         GdkEventButton *event,
+                         gpointer     data);
 gboolean da_unpress_event (GtkWidget    *da,
-			   GdkEventButton *event,
-			   gpointer     data);
+                           GdkEventButton *event,
+                           gpointer     data);
 gboolean da_notify_event (GtkWidget     *da,
-			  GdkEventMotion *event,
-			  gpointer      data);
+                          GdkEventMotion *event,
+                          gpointer      data);
 GtkWidget *create_drawing_area();
 GtkWidget *create_player_control_frame(GtkTreeView *tree_view);
 
@@ -183,10 +187,14 @@ GtkWidget *create_player_control_frame(GtkTreeView *tree_view);
 void file_chooser_cancel_event();
 void file_chooser_ok_event(gchar *fname);
 void browse_button_event( GtkWidget *widget,
-			  gpointer   data );
+                          gpointer   data );
 void close_file_popup_window_event( GtkWidget *window,
-				    gpointer data );
+                                    gpointer data );
 void handle_file_detached_event (GtkHandleBox *handlebox,
-				 GtkWidget *widget,
-				 gpointer data);
+                                 GtkWidget *widget,
+                                 gpointer data);
 GtkWidget *create_choose_file_frame();
+
+void change_current_filename(gchar *fname);
+GtkWidget *create_player_playlist_frame();
+
