@@ -3,7 +3,7 @@
  * mp3splt-gtk -- utility based on mp3splt,
  *                for mp3/ogg splitting without decoding
  *
- * Copyright (c) 2005-2006 Munteanu Alexandru - io_alex_2002@yahoo.fr
+ * Copyright (c) 2005-2009 Alexandru Munteanu - io_fx@yahoo.fr
  *
  *
  * http://mp3splt.sourceforge.net/
@@ -36,17 +36,18 @@
  *
  *********************************************************/
 
-#define SELECTED_SPLIT_NORMAL 4
-#define SELECTED_SPLIT_TIME 3
-#define SELECTED_SPLIT_SILENCE 2
+#define SELECTED_SPLIT_NORMAL 3
+#define SELECTED_SPLIT_TIME 2
 #define SELECTED_SPLIT_WRAP 1
 #define SELECTED_SPLIT_ERROR 0
 
+#define NUMBER_OF_SPLIT_MODES 4
+
 gint get_selected_split_mode(GtkToggleButton *radio_b);
 void deactivate_silence_parameters();
 void activate_silence_parameters();
 void split_mode_changed (GtkToggleButton *radio_b,
-			 gpointer data);
+                         gpointer data);
 void set_default_split_modes (GtkWidget *widget, 
-			      gpointer data);
+                              gpointer data);
 GtkWidget *create_special_split_page();
