@@ -3,7 +3,7 @@
  * mp3splt-gtk -- utility based on mp3splt,
  *                for mp3/ogg splitting without decoding
  *
- * Copyright (c) 2005-2006 Munteanu Alexandru - io_alex_2002@yahoo.fr
+ * Copyright (c) 2005-2009 Alexandru Munteanu - io_fx@yahoo.fr
  *
  * http://mp3splt.sourceforge.net/
  *
@@ -35,7 +35,7 @@
  *
  *********************************************************/
 
-gint is_filee(gchar *fname);
+gint is_filee(const gchar *fname);
 gint check_if_we_have_player();
 gchar *get_preferences_filename();
 gint check_if_different_from_config_file();
